==> lima-1.0.6.tar.gz: lima-1.0.6/website/content/en/docs/talks/_index.md <==
---
title: Talks
weight: 450
---

## 2022
### KubeCon + CloudNativeCon Europe 2022

[Akihiro Suda](https://github.com/AkihiroSuda) and [Jan Dubois](https://github.com/jandubois) presented "Running containerd and k3s on macOS" about Lima.

> It has been very hard to use Mac for developing containerized apps. A typical way is to use Docker for Mac, but it is not FLOSS. Another option is to install Docker and/or Kubernetes into VirtualBox, often via minikube, but it doesn't propagate localhost ports, and VirtualBox also doesn't support the ARM architecture. This session will show how to run containerd and k3s on macOS, using Lima and Rancher Desktop. Lima wraps QEMU in a simple CLI, with neat features for container users, such as filesystem sharing and automatic localhost port forwarding, as well as DNS and proxy propagation for enterprise networks. Rancher Desktop wraps Lima with k3s integration and GUI.

Read the [slides](https://static.sched.com/hosted_files/kccnceu2022/5f/lima.pdf) or watch the [video](https://www.youtube.com/watch?v=g5GCsbjkzRM).

### CNCF TAG-Runtime Meeting 2022-10-06

[Akihiro Suda](https://github.com/AkihiroSuda) presented Lima in [the CNCF TAG-Runtime Meeting](https://github.com/cncf/tag-runtime).

Read the [slides](https://www.slideshare.net/AkihiroSuda/cncf-tagruntime-20221006-limapdf).

## 2023
### DevOps Toolkit 2023-02-09

[Anders Björklund](https://github.com/afbjorklund) presented Lima in [The DevOps Toolkit Series](https://www.devopstoolkitseries.com/).

Watch the [video](https://www.youtube.com/watch?v=GDInFocQJTU).

### KubeCon + CloudNativeCon Europe 2023

[Akihiro Suda](https://github.com/AkihiroSuda) presented Lima in the CNCF project pavilion.

Read the [slides](https://www.slideshare.net/AkihiroSuda/kubeconeu2023-lima-pavilion).

==> lima-1.2.1.tar.gz: lima-1.2.1/website/content/en/docs/talks/_index.md <==
---
title: Talks
weight: 450
---

## 2022
### KubeCon + CloudNativeCon Europe 2022

[Akihiro Suda](https://github.com/AkihiroSuda) and [Jan Dubois](https://github.com/jandubois) presented "Running containerd and k3s on macOS" about Lima.

> It has been very hard to use Mac for developing containerized apps. A typical way is to use Docker for Mac, but it is not FLOSS. Another option is to install Docker and/or Kubernetes into VirtualBox, often via minikube, but it doesn't propagate localhost ports, and VirtualBox also doesn't support the ARM architecture. This session will show how to run containerd and k3s on macOS, using Lima and Rancher Desktop. Lima wraps QEMU in a simple CLI, with neat features for container users, such as filesystem sharing and automatic localhost port forwarding, as well as DNS and proxy propagation for enterprise networks. Rancher Desktop wraps Lima with k3s integration and GUI.

Read the [slides](https://static.sched.com/hosted_files/kccnceu2022/5f/lima.pdf) or watch the [video](https://www.youtube.com/watch?v=g5GCsbjkzRM).

### CNCF TAG-Runtime Meeting 2022-10-06

[Akihiro Suda](https://github.com/AkihiroSuda) presented Lima in [the CNCF TAG-Runtime Meeting](https://github.com/cncf/tag-runtime).

Read the [slides](https://www.slideshare.net/AkihiroSuda/cncf-tagruntime-20221006-limapdf).

## 2023
### DevOps Toolkit 2023-02-09

[Anders Björklund](https://github.com/afbjorklund) presented Lima in The DevOps Toolkit Series.

Watch the [video](https://www.youtube.com/watch?v=GDInFocQJTU).

### KubeCon + CloudNativeCon Europe 2023

[Akihiro Suda](https://github.com/AkihiroSuda) presented Lima in the CNCF project pavilion.

Read the [slides](https://www.slideshare.net/AkihiroSuda/kubeconeu2023-lima-pavilion).
